#include "Character_LCM.h"
#include "mcc_generated_files/config/clock_config.h"
#include "mcc_generated_files/include/pin_manager.h"

#define SystemFrequency F_CPU

// Makesure at least one cycle delay (+1)
#define IntLCM_Delay1ns ((( SystemFrequency * 1 ) / 1000000000L) + 1)
#define IntLCM_Delay10ns ((( SystemFrequency * 10 ) / 1000000000L) + 1)
#define IntLCM_Delay100ns ((( SystemFrequency * 100 ) / 1000000000L) + 1)

#define IntLCM_Delay1us ((( SystemFrequency * 1 ) / 1000000L) + 1)
#define IntLCM_Delay10us ((( SystemFrequency * 10 ) / 1000000L) + 1)
#define IntLCM_Delay100us ((( SystemFrequency * 100 ) / 1000000L) + 1)

#define IntLCM_Delay1ms ((( SystemFrequency * 1 ) / 1000L) + 1)
#define IntLCM_Delay10ms ((( SystemFrequency * 10 ) / 1000L) + 1)
#define IntLCM_Delay100ms ((( SystemFrequency * 100 ) / 1000L) + 1)

// " / 10 " <- Fix C Code Function

void LCM_IOSetup( void )
{
	LCD_RS_set_level(0);
	LCD_RW_set_level(0);
	LCD_E_set_level(0);

	LED18_SEGO_DB7_set_level(0);
	LED17_SEGG_DB6_set_level(0);
	LED16_SEGF_DB5_set_level(0);
	LED15_SEGE_DB4_set_level(0);
}

// Apply volatile feature for optimal avoid
void LCM_Delay( volatile unsigned long Count )
{
	while( Count-- );
}

void IntLCM_Communication( unsigned char NibbleByte )
{
	unsigned char Temporary;
	//Temporary = NibbleByte & 0x0f;

	LCM_Delay(IntLCM_Delay10ns * 4); // tAS

	LED18_SEGO_DB7_set_level(0);
	LED17_SEGG_DB6_set_level(0);
	LED16_SEGF_DB5_set_level(0);
	LED15_SEGE_DB4_set_level(0);

	Temporary = NibbleByte & 0x0f;
	if( (Temporary & 0x08) == 0x08 ) // D7
		LED18_SEGO_DB7_set_level(1);

	Temporary = NibbleByte & 0x0f;
	if( (Temporary & 0x04) == 0x04 ) // D6
		LED17_SEGG_DB6_set_level(1);

	Temporary = NibbleByte & 0x0f;
	if( (Temporary & 0x02) == 0x02 ) // D5
		LED16_SEGF_DB5_set_level(1);

	Temporary = NibbleByte & 0x0f;
	if( (Temporary & 0x01) == 0x01 ) // D4
		LED15_SEGE_DB4_set_level(1);

	LCD_E_set_level(1);
	LCM_Delay(IntLCM_Delay100ns * 2.3); //PWEH

	LCD_E_set_level(0);
	LCM_Delay(IntLCM_Delay10ns); //tAH
}

unsigned char LCM_IsBusy( void )
{

	/*
		unsigned char Temporary;

		PMPSetAddress( LCM_INSTRUCTION );
		Temporary = mPMPMasterReadByte( );		// Dummy Read for trigger PMP active.

		while( !INTGetFlag( INT_PMP ) );		// Wait PMP Complete.
		INTClearFlag( INT_PMP );

		Temporary = mPMPMasterReadByte( );

		return ( ( Temporary >> 7 ) & 0x01 ); 
	 */

	unsigned int i;

	for( i = 0; i < 1000; i++ );
	return 0;
}

void IntLCM_WriteData( unsigned char Data )
{
	while( LCM_IsBusy() );
	LCD_RS_set_level(1); // RS = 1 , Data
	LCD_RW_set_level(0);

	IntLCM_Communication((Data >> 4) & 0x0f);
	IntLCM_Communication(Data & 0x0f);
}

void IntLCM_WriteInstruction( unsigned char Instruction )
{
	while( LCM_IsBusy() );
	LCD_RS_set_level(0); // RS = 0 , Instruction
	LCD_RW_set_level(0);

	IntLCM_Communication((Instruction >> 4) & 0x0f);
	IntLCM_Communication(Instruction & 0x0f);
}

void LCM_Init( void )
{
	LCM_IOSetup();

	LCD_RS_set_level(0); // RS = 0 , Instruction
	LCD_RW_set_level(0);

	IntLCM_Communication(0x03); // Reset
	LCM_Delay(IntLCM_Delay1ms * 4.1); // Wait 4.1 mSecs

	IntLCM_Communication(0x03); // Reset
	LCM_Delay(IntLCM_Delay100us); // Wait 100 uSecs

	IntLCM_Communication(0x03); // Reset
	LCM_Delay(IntLCM_Delay100us); // Wait 100 uSecs

	IntLCM_Communication(0x02);
	LCM_Delay(IntLCM_Delay100us); // Wait 100 uSecs

	IntLCM_Communication((0x28 >> 4) & 0x0f);
	IntLCM_Communication(0x28 & 0xf);
	LCM_Delay(IntLCM_Delay10us * 3.7);

	IntLCM_Communication((Disp_Off >> 4) & 0x0f); // Dsplay Off
	IntLCM_Communication(Disp_Off & 0xf);
	LCM_Delay(IntLCM_Delay10us * 3.7);

	IntLCM_Communication((Disp_Clear >> 4) & 0x0f); // Dsplay Clear
	IntLCM_Communication(Disp_Clear & 0xf);
	LCM_Delay(IntLCM_Delay1ms * 1.52);

	IntLCM_Communication((Disp_Entry_Inc >> 4) & 0x0f); // Entry Mode
	IntLCM_Communication(Disp_Entry_Inc & 0xf);
	LCM_Delay(IntLCM_Delay10us * 3.7);

	IntLCM_Communication((Disp_On >> 4) & 0x0f); // Display On
	IntLCM_Communication(Disp_On & 0xf);
	LCM_Delay(IntLCM_Delay10us * 3.7);
}

void LCM_SetCursor( unsigned char X, unsigned char Y )
{
	IntLCM_WriteInstruction((0x80 + (Y * 0x40) + X));
}

void LCM_PutASCII( unsigned char Ascii )
{
	IntLCM_WriteData(Ascii);
}

void LCM_PutHex( unsigned char Hex )
{
	unsigned char Temporary;

	Temporary = (Hex >> 4) & 0x0f;

	if( Temporary > 9 )
		Temporary += 0x37;
	else
		Temporary += '0';

	IntLCM_WriteData(Temporary);

	Temporary = Hex & 0x0f;
	if( Temporary > 9 )
		Temporary += 0x37;
	else Temporary += '0';
	IntLCM_WriteData(Temporary);
}

void LCM_PutROMString( const unsigned char *String )
{
	while( *String != 0x00 )
		IntLCM_WriteData(*String++);
}

void LCM_PutRAMString( unsigned char *String )
{
	while( *String != 0x00 )
		IntLCM_WriteData(*String++);
}

static unsigned char Disable_Zero = 1;

unsigned char LCM_BCD_Regulate( unsigned char BCD )
{
	if( BCD == 0 )
	{
		if( Disable_Zero == 1 )
			return ' ';
		else
			return '0';
	}

	else
	{
		Disable_Zero = 0;
		return ( BCD += '0');
	}
}

void LCM_PutNumber( unsigned int Number, unsigned char Digit )
{
	unsigned char Temporary;
	Disable_Zero = 1;

	switch( Digit )
	{
	default:
	case 4:
		Temporary = LCM_BCD_Regulate((Number % 10000) / 1000);
		IntLCM_WriteData(Temporary);

	case 3:
		Temporary = LCM_BCD_Regulate((Number % 1000) / 100);
		IntLCM_WriteData(Temporary);

	case 2:
		Temporary = LCM_BCD_Regulate((Number % 100) / 10);
		IntLCM_WriteData(Temporary);

	case 1:
		Disable_Zero = 0;
		Temporary = LCM_BCD_Regulate(Number % 10);
		IntLCM_WriteData(Temporary);
	}
}
