/*
    (c) 2018 Microchip Technology Inc. and its subsidiaries. 
    
    Subject to your compliance with these terms, you may use Microchip software and any 
    derivatives exclusively with Microchip products. It is your responsibility to comply with third party 
    license terms applicable to your use of third party software (including open source software) that 
    may accompany Microchip software.
    
    THIS SOFTWARE IS SUPPLIED BY MICROCHIP "AS IS". NO WARRANTIES, WHETHER 
    EXPRESS, IMPLIED OR STATUTORY, APPLY TO THIS SOFTWARE, INCLUDING ANY 
    IMPLIED WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY, AND FITNESS 
    FOR A PARTICULAR PURPOSE.
    
    IN NO EVENT WILL MICROCHIP BE LIABLE FOR ANY INDIRECT, SPECIAL, PUNITIVE, 
    INCIDENTAL OR CONSEQUENTIAL LOSS, DAMAGE, COST OR EXPENSE OF ANY KIND 
    WHATSOEVER RELATED TO THE SOFTWARE, HOWEVER CAUSED, EVEN IF MICROCHIP 
    HAS BEEN ADVISED OF THE POSSIBILITY OR THE DAMAGES ARE FORESEEABLE. TO 
    THE FULLEST EXTENT ALLOWED BY LAW, MICROCHIP'S TOTAL LIABILITY ON ALL 
    CLAIMS IN ANY WAY RELATED TO THIS SOFTWARE WILL NOT EXCEED THE AMOUNT 
    OF FEES, IF ANY, THAT YOU HAVE PAID DIRECTLY TO MICROCHIP FOR THIS 
    SOFTWARE.
*/

//#include <stdio.h>
//#include <string.h>
#include "mcc_generated_files/mcc.h"
#include "Character_LCM.h"

/*
    Main application
*/
#define USART_TX_ENABLE 1   // LED1 Co-net with USART3 TX
#define COM5_ENABLE		1	// LED2 Co-net with COM5
#define BUZZER_ENABLE	1	// LED4 Co-net with Buzzer BZ1
volatile bool SW1_down = false;
volatile bool SW2_down = false;
volatile bool ADC_Ready=0;
volatile uint16_t ADC_Result;
volatile uint8_t DigitNumber[4];

// 7-Segment LED digits table
//   A     |    0
// F   B   |  5   1
//   G     |    6
// E   C   |  4   2
//   D   O |    3   7
//						    // Bit 7654 3210
#define DIGI_0		0x3F	//     0011 1111  
#define DIGI_1		0x06	//     0000 0110  
#define DIGI_2		0x5B	//     0101 1011
#define DIGI_3		0x4F	//     0100 1111
#define DIGI_4		0x66	//     0110 0110
#define DIGI_5		0x6D	//     0110 1101
#define DIGI_6		0x7D	//     0111 1101
#define DIGI_7		0x07	//     0000 0111
#define DIGI_8		0x7F	//     0111 1111
#define DIGI_9		0x6F	//     0110 1111
#define DIGI_DOT	0x80	//     1000 0000
unsigned char DIGI[11] = { DIGI_0, DIGI_1, DIGI_2, DIGI_3, DIGI_4,
						   DIGI_5, DIGI_6, DIGI_7, DIGI_8, DIGI_9,
						   DIGI_DOT };

void ScanningCOM()
{	
	static uint8_t COM_Idx=0;
	static uint8_t LEDIdx=0;
	static uint8_t Step=1;
	static uint8_t ScanSpeed=0;
	
	if( COM_Idx < 4 )
	{
		// Update current 7-SEG digit number
		PORTC_set_port_level(DIGI[DigitNumber[COM_Idx]], true);		

		// Enable current 7-SEG Display
		if( COM_Idx==0 )
		{	
			// 1000 digit
			COM1_set_level( true );
		}
		else if( COM_Idx==1 )
		{
			// 100 digit
			COM2_set_level( true );
		}
		else if( COM_Idx==2 )
		{
			// 10 digit
			COM3_set_level( true );
		}
		else if( COM_Idx==3 )
		{
			// 1 digit
			COM4_set_level( true );
		}
	}
	else
	{
		// Update current LED
		PORTC_set_port_level(1<<LEDIdx, true);
		
		// Enable LEDs
		LED2_COM5_set_level( true );
		
		// Adjust LED scan speed depend on ADC value
		if( ScanSpeed++ >= (ADC_Result>>6) )
		{
			ScanSpeed=0;
			LEDIdx += Step;
			if     ( LEDIdx==7 && Step!=0 ) Step=0;
			else if( LEDIdx==7 && Step==0 ) Step=-1;
			else if( LEDIdx==0 && Step!=0 ) Step= 0;
			else if( LEDIdx==0 && Step==0 ) Step= 1;
		}			
	}

	// Scanning COM
	COM_Idx = (COM_Idx+1) % 5;	
}

void SW1_CB()
{
	// Interrupt sensing Low Level of Button Input
	SW1_down = true;
}

void SW2_CB()
{
	// Interrupt sensing Low Level of Button Input
	SW2_down = true;
}

// TCA0
// Clock Source = System Clock/256 = 10MHz/256 = 39.062KHz
// Mode = Single Slop PWM
// Period = PERBUF = 39062 (0x9896) => 1sec
// OVF  = 39062/1 = 39062 (0x9896) => Shift 1sec
// CMP0 = 39062/2 = 19531 (0x4C4B) => Shift 500ms (Clock output on PF0)
// CMP1 = 39062/4 =  9766 (0x2626) => Shift 250ms (Clock output on PF1)
// CMP2 = 39062/8 =  4883 (0x1313) => Shift 125ms (Clock output on PF1)
void TCA0_CMP0_CB()
{
#if !COM5_ENABLE	
	// Toggle LED2 (Co-net with COM5)
	LED2_COM5_toggle_level();
#endif	
}

// CMP1 = 39062/4 =  9766 (0x2626) => Shift 250ms (Clock output on PF1)
void TCA0_CMP1_CB()
{
	// Toggle LED3
	LED3_toggle_level();
}

// CMP2 = 39062/8 =  4883 (0x1313) => Shift 125ms (Clock output on PF1)
void TCA0_CMP2_CB()
{
#if !BUZZER_ENABLE	
	// Toggle LED4 (Co-net with Buzzer BZ1)
	LED4_BZ1_toggle_level();
#endif
	
	// Dark LED2 on APP-AVR4809-1
	LED2_4809_set_level( 1 );
}

// OVF  = 39062/1 = 39062 (0x9896) => Shift 1sec
void TCA0_OVF_CB()
{
#if !USART_TX_ENABLE	
	// Toggle LED1 (Co-net with USART3 TX)
	LED1_TXD_toggle_level();
#endif	
	
	// Light LED2 on APP-AVR4809-1
	LED2_4809_set_level( 0 );
}

// TCB0
// Clock Source = CLK_PER/2 = 10MHz/2 = 5MHz
// Mode = Periodic Interrupt
// Period = CCMP = 5000 => 5000/5M = 1ms
// ADC conversion interval is 1ms x 100 = 100ms
// Update LCM in 1ms x 100 = 100ms
// Update each LED and 7-SEG digit in 1ms x 5(COM) = 5ms, except doing ADC conversion
// Toggle LED4 and buzzer frequency depend to ADC value
void TCB0_CB()
{	
	static uint32_t Interval=0;

	// Disable 7-SEG and LEDs
	COM1_set_level( false );
	COM2_set_level( false );
	COM3_set_level( false );
	COM4_set_level( false );
	LED2_COM5_set_level( false );

	// Clear all LEDs
	PORTC_set_port_level(0xFF, false);
	
	if( (Interval%100)==0 )
	{		
		// Update ADC value to LCM
		LCM_SetCursor(6, 1);
		LCM_PutNumber(ADC_Result, 4);			
		
		// Start ADC conversion
		ADC_0_start_conversion( ADC_MUXPOS_AIN0_gc );	
	}
	else
	{
		// Update 7-SEG digit and LEDs
		ScanningCOM();
	}
	
#if BUZZER_ENABLE		
	if( (Interval%ADC_Result)==0 )
	{
		LED4_BZ1_toggle_level();
	}		
#endif	
	
	Interval++;
}

void ADC0_RDY_CB()
{
	uint16_t R;
	
	// Get ADC Conversion Result
	ADC_Result = ADC_0_get_conversion_result();
	
	// Assign PWM duty to Hi-Byte of TCB1 (8-bit PWM Mode)
	// TCB1 
	// Clock Source = TCA0 = System Clock/256 = 10MHz/256 = 39.062KHz
	// Mode = 8-bit PWM
	// CCMP = 0xFFFF
	// Period = CCMPL = 0xFF => 255/(10MHz/256) = 255/39062 = 6.528ms
	// Dufy   = CCMPH = 0x00 ~ 0xFF
	TCB1.CCMPH = ((uint32_t)ADC_Result*0xFF/1023);

	// Convert ADC result to 4 digits number for 7-SEG display.
	R=ADC_Result;
	DigitNumber[0]=R/1000;
	R %= 1000;
	DigitNumber[1]=R/100;
	R %= 100;
	DigitNumber[2]=R/10;
	R %= 10;
	DigitNumber[3]=R;
	
	// Assign software flag.
	ADC_Ready = true;
}

int main(void)
{
    /* Initializes MCU, drivers and middleware */
    SYSTEM_Initialize();

#if !USART_TX_ENABLE
	// Disable USART3 pin connection for LED1 control
	PORTMUX.USARTROUTEA = 0xC0;	
#endif
	
	LCM_Init();

	LCM_SetCursor(0, 0);
	LCM_PutROMString((const unsigned char *) "ATMEGA4809  DEMO");
	LCM_SetCursor(0, 1);
	LCM_PutROMString((const unsigned char *) "VR1 :           ");
	printf( "\r\nMCC on ATMega4809 demo. \r\nPress SW2 to Start.\r\n" );
	
	// Wait SW1 push down
	while( !SW2_down );
	printf( "Started.\r\n" );
	
	// Register TCA0 Compare 0/1/2 callabck
	TCA_0_Set_CMP0_ISR_cb( TCA0_CMP0_CB );
	TCA_0_Set_CMP1_ISR_cb( TCA0_CMP1_CB );
	TCA_0_Set_CMP2_ISR_cb( TCA0_CMP2_CB );
	// Register TCA0 Overflow callabck
	TCA_0_Set_OVF_ISR_cb( TCA0_OVF_CB );
	// Register TCB0 callabck
	TCB_0_Set_CAPT_ISR_cb( TCB0_CB );
		
	// Register ADC0 conversion ready callback
	ADC_0_register_callback( ADC0_RDY_CB );
	ADC_0_start_conversion( ADC_MUXPOS_AIN0_gc );
		
	/* Replace with your application code */
    while (1)
	{
		if( ADC_Ready )
		{
			ADC_Ready = 0;
			// Output ADC result to USART
			printf( "VR1 = %4d \r", ADC_Result );
		}
    }
}
/**
    End of File
*/