/*
    (c) 2018 Microchip Technology Inc. and its subsidiaries. 
    
    Subject to your compliance with these terms, you may use Microchip software and any 
    derivatives exclusively with Microchip products. It is your responsibility to comply with third party 
    license terms applicable to your use of third party software (including open source software) that 
    may accompany Microchip software.
    
    THIS SOFTWARE IS SUPPLIED BY MICROCHIP "AS IS". NO WARRANTIES, WHETHER 
    EXPRESS, IMPLIED OR STATUTORY, APPLY TO THIS SOFTWARE, INCLUDING ANY 
    IMPLIED WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY, AND FITNESS 
    FOR A PARTICULAR PURPOSE.
    
    IN NO EVENT WILL MICROCHIP BE LIABLE FOR ANY INDIRECT, SPECIAL, PUNITIVE, 
    INCIDENTAL OR CONSEQUENTIAL LOSS, DAMAGE, COST OR EXPENSE OF ANY KIND 
    WHATSOEVER RELATED TO THE SOFTWARE, HOWEVER CAUSED, EVEN IF MICROCHIP 
    HAS BEEN ADVISED OF THE POSSIBILITY OR THE DAMAGES ARE FORESEEABLE. TO 
    THE FULLEST EXTENT ALLOWED BY LAW, MICROCHIP'S TOTAL LIABILITY ON ALL 
    CLAIMS IN ANY WAY RELATED TO THIS SOFTWARE WILL NOT EXCEED THE AMOUNT 
    OF FEES, IF ANY, THAT YOU HAVE PAID DIRECTLY TO MICROCHIP FOR THIS 
    SOFTWARE.
*/

#include "../include/tcb0.h"

/**
 * \brief Initialize tcb interface
 *
 * \return Initialization status.
 */

void (TCB_0_default_CAPT_isr_cb)(void);

void (*TCB_0_CAPT_isr_cb)(void) = &TCB_0_default_CAPT_isr_cb;

void TCB_0_default_CAPT_isr_cb(void)
{
	//Add your ISR code here
}

void TCB_0_Set_CAPT_ISR_cb(TCB_0_cb_t cb)
{
	TCB_0_CAPT_isr_cb = cb;
}

ISR(TCB0_INT_vect)
{
	/* Insert your TCB interrupt handling code */

	/**
	 * The interrupt flag is cleared by writing 1 to it, or when the Capture register
	 * is read in Capture mode
	 */
	 
	if (TCB_0_CAPT_isr_cb != NULL)
        {
            (*TCB_0_CAPT_isr_cb)();
        } 
	 
	TCB0.INTFLAGS = TCB_CAPT_bm;
}

/**
 * \brief Initialize TCB interface
 */
int8_t TCB_0_init()
{

		TCB0.CCMP = 5000; /* Compare or Capture */

	// 	TCB0.CNT = 0; /* Count */

	
	// 	TCB0.CTRLB = 0 << TCB_ASYNC_bp /* Asynchronous Enable: disabled */
	// 				| 0 << TCB_CCMPEN_bp /* Pin Output Enable: disabled */
	// 				| 0 << TCB_CCMPINIT_bp /* Pin Initial State: disabled */
	// 				| TCB_CNTMODE_INT_gc; /* Timer Mode: Periodic Interrupt */

	// 	TCB0.DBGCTRL = 0 << TCB_DBGRUN_bp; /* Debug Run: disabled */

	// 	TCB0.EVCTRL = 0 << TCB_CAPTEI_bp /* Event Input Enable: disabled */
	// 				| 0 << TCB_EDGE_bp /* Event Edge: disabled */
	// 				| 0 << TCB_FILTER_bp; /* Input Capture Noise Cancellation Filter: disabled */

		TCB0.INTCTRL = 1 << TCB_CAPT_bp; /* Capture or Timeout: enabled */
        
	// 	TCB0.INTFLAGS = 0 << TCB_CAPT_bp; /* Capture or Timeout: disabled */

	// 	TCB0.TEMP = 0; /* Temporary Value */

	TCB0.CTRLA = TCB_CLKSEL_CLKDIV2_gc /* Clock Select: CLK_PER/2 (From Prescaler) */
					| 1 << TCB_ENABLE_bp /* Enable: enabled */
					| 0 << TCB_RUNSTDBY_bp /* Run Standby: disabled */
					| 0 << TCB_SYNCUPD_bp; /* Synchronize Update: disabled */

	return 0;
}

void TCB_0_WriteTimer(uint16_t timerVal)
{
	TCB0.CNT=timerVal;
}

uint16_t TCB_0_ReadTimer(void)
{
	uint16_t readVal;

	readVal = TCB0.CNT;

	return readVal;
}

void TCB_0_EnableInterrupt(void)
{
	TCB0.INTCTRL = 1 << TCB_CAPT_bp; /* Capture or Timeout: enabled */
}
void TCB_0_DisableInterrupt(void)
{
	TCB0.INTCTRL = 0 << TCB_CAPT_bp; /* Capture or Timeout: disabled */

}